Required for the next patch.

Signed-off-by: Hannes Reinecke <h...@suse.com>
---
 drivers/scsi/scsi_transport_fc.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/scsi/scsi_transport_fc.c b/drivers/scsi/scsi_transport_fc.c
index 0f3a386..4534085 100644
--- a/drivers/scsi/scsi_transport_fc.c
+++ b/drivers/scsi/scsi_transport_fc.c
@@ -2592,7 +2592,7 @@ static void fc_terminate_rport_io(struct fc_rport *rport)
 
 
 /**
  * fc_rport_create - allocates and creates a remote FC port.
  * @shost:     scsi host the remote port is connected to.
  * @channel:   Channel on shost port connected to.
  * @ids:       The world wide names, fc address, and FC4 port
@@ -2605,8 +2605,8 @@ static void fc_terminate_rport_io(struct fc_rport *rport)
  *     This routine assumes no locks are held on entry.
  */
 static struct fc_rport *
-fc_rport_create(struct Scsi_Host *shost, int channel,
-       struct fc_rport_identifiers  *ids)
+fc_remote_port_create(struct Scsi_Host *shost, int channel,
+                     struct fc_rport_identifiers  *ids)
 {
        struct fc_host_attrs *fc_host = shost_to_fc_host(shost);
        struct fc_internal *fci = to_fc_internal(shost->transportt);
@@ -2914,7 +2914,7 @@ struct fc_rport *
        spin_unlock_irqrestore(shost->host_lock, flags);
 
        /* No consistent binding found - create new remote port entry */
-       rport = fc_rport_create(shost, channel, ids);
+       rport = fc_remote_port_create(shost, channel, ids);
 
        return rport;
 }
@@ -2592,7 +2592,7 @@ static void fc_terminate_rport_io(struct fc_rport *rport)
 
 /**
- * fc_rport_create - allocates and creates a remote FC port.
+ * fc_remote_port_create - allocates and creates a remote FC port.
  * @shost:     scsi host the remote port is connected to.
  * @channel:   Channel on shost port connected to.
-- 
1.8.5.6

--
To unsubscribe from this list: send the line "unsubscribe linux-scsi" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to